pub struct InstagramPost {Show 31 fields
pub alt: Option<String>,
pub audio_url: Option<String>,
pub caption: String,
pub child_posts: Vec<InstagramChildPost>,
pub comments_count: u64,
pub dimensions_height: u64,
pub dimensions_width: u64,
pub display_url: String,
pub first_comment: String,
pub hashtags: Vec<String>,
pub id: String,
pub images: Vec<String>,
pub input_url: String,
pub is_comments_disabled: bool,
pub is_pinned: Option<bool>,
pub latest_comments: Vec<InstagramComment>,
pub likes_count: Option<u64>,
pub mentions: Vec<String>,
pub music_info: Option<InstagramMusicInfo>,
pub owner_full_name: String,
pub owner_id: String,
pub owner_username: String,
pub product_type: Option<String>,
pub short_code: String,
pub timestamp: Option<DateTime<Utc>>,
pub post_type: String,
pub url: String,
pub video_duration: Option<f64>,
pub video_play_count: Option<u64>,
pub video_url: Option<String>,
pub video_view_count: Option<u64>,
}Expand description
One Instagram post (image, video, reel, or sidecar/carousel).
Fields mirror the JSON produced by the Apify Instagram Profile Scraper. Many are optional because the available metadata depends on the post type and whether the Actor was configured to fetch comments / child posts.
Fields
alt: Option<String>audio_url: Option<String>caption: Stringchild_posts: Vec<InstagramChildPost>comments_count: u64dimensions_height: u64dimensions_width: u64display_url: Stringfirst_comment: Stringid: Stringimages: Vec<String>input_url: Stringis_comments_disabled: boolis_pinned: Option<bool>latest_comments: Vec<InstagramComment>likes_count: Option<u64>mentions: Vec<String>music_info: Option<InstagramMusicInfo>owner_full_name: Stringowner_id: Stringowner_username: Stringproduct_type: Option<String>short_code: Stringtimestamp: Option<DateTime<Utc>>post_type: Stringurl: Stringvideo_duration: Option<f64>video_play_count: Option<u64>video_url: Option<String>video_view_count: Option<u64>Trait Implementations
Sourceimpl Clone for InstagramPost
impl Clone for InstagramPost
Sourceimpl Debug for InstagramPost
impl Debug for InstagramPost
Sourceimpl<'de> Deserialize<'de> for InstagramPost
impl<'de> Deserialize<'de> for InstagramPost
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more